# ALICE - Automated Labeling of Independent Components for EEG

The project aims to develop a sustainable algorithm for EEG IC artifact removal and collect a publically available dataset

`alice-ml` library contains pretrained ML models to label IC. It's compatible with [MNE](https://mne.tools/stable/index.html) library.

## Requirements

* Python >= 3.7

## Installation

Currently only pip installation is supported

```
pip install alice-ml
```
